a {
    cursor: pointer;
}

.disabled {
    pointer-events: auto;
}

.btn {
    min-height: 26px;
    min-width: 26px;
}

.btn.disabled {
    pointer-events: auto;
}

.btn.disabled:hover {
  z-index: auto;
}

a.disabled {
    cursor: not-allowed !important;
    text-decoration: none;
    pointer-events: none;
    color: #8b8d8f;
}

a.disabled:hover {
    text-decoration: none;
}

.dropdown-menu > li > a.disabled,
.dropdown-menu > li > a.disabled:hover,
.dropdown-menu > li > a.disabled:focus {
  color: #999999;
}

.dropdown-menu > li > a.disabled:hover,
.dropdown-menu > li > a.disabled:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  cursor: default;
}

/* Limit dropdown menus to 90% of the viewport size */
.dropdown-menu {
    height: auto;
    overflow-x: hidden;
    max-height: 90vh;
}
/* Align these buttons more nicely */
.btn.fa-minus,
.btn.fa-plus {
    padding-top: 4px;
}

/* HACK: Workaround for https://github.com/patternfly/patternfly/issues/174*/

.page-ct {
    margin-top: 20px;
}

.highlight-ct {
    background-color: #d4edfa;
}

/* Well and Blankslate */

.curtains-ct {
    top: 0px;
    height: 100%;
    width: 100%;
    position: fixed;
}

.panel .well {
    margin-bottom: 0px;
    border: none;
    border-radius: 0px;
    background-color: #FAFAFA;
}

.well.blank-slate-pf {
    box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.05) inset;
    padding-top: 40px;
}

.blank-slate-pf .spinner-lg {
    height: 58px;
    width: 58px;
}

/*
 * Control buttons such as play and stop
 * Used with .btn .btn-default
 */

.btn-control-ct,
.btn-control-ct:hover {
    background-position: center center;
    background-size: 16px 16px;
    background-repeat: no-repeat;
    background-image: none;
    -webkit-border-radius: 2;
    -moz-border-radius: 2;
    border-radius: 2px;
    height: 28px;
    width: 28px;
    box-shadow: none;
}

.btn-control-ct {
    background-color: #eeeeee;
}

.btn-control-ct:hover {
   background-color: #e0e0e0;
}


/* On/off switch */

.btn-onoff-ct {
    margin: 1px 0px;
    text-transform: uppercase;
}

.btn-onoff-ct .btn {
    color: transparent;
    border-color: #B7B7B7;
    padding: 2px 6px 1px 6px;
    background-color: white;
    background-image: linear-gradient(to bottom, rgb(250, 250, 250) 0px, rgb(237, 237, 237) 100%);
    -webkit-box-shadow: none;
    box-shadow: none;
    width: 37px;
}

.btn-onoff-ct .btn:first-child {
    border-right: #00435F;
}

.btn-onoff-ct .btn:last-child {
    border-left: #00435F;
    padding-left: 5px;
}

.btn-onoff-ct .btn.active {
    background-image: none;
    width: 36px;
}

.btn-onoff-ct .btn.active:first-child {
    background-color: #0086CF;
    color: white;
    border-right: 1px solid #0071b0;
}

.btn-onoff-ct .btn.active:last-child {
    color: #000;
    border-left: 1px solid #d6d6d6;
}

.btn-onoff-ct .btn.disabled {
    pointer-events: none;
    color: transparent !important;
}

.btn-onoff-ct .btn.active.disabled {
    background-color: #888 !important;
    color: white !important;
}

/* Small list inside a dialog */
/* Alert fixups */

/* HACK: word-wrap workaround for long alerts https://github.com/patternfly/patternfly/issues/491 */

.modal-content .alert {
    text-align: left;
    padding-top: 5px;
    padding-bottom: 5px;
    word-wrap: break-word;
}

.modal-content .alert .fa {
    position: absolute;
    left: 10px;
    top: 6px;
    font-size: 20px;
}

.modal-content .alert .pficon {
    top: 5px;
}

.alert.alert-danger .fa {
    color: #af151a;
}

/* Dialog patterns */

.dialog-wait-ct {
    margin-top: 3px;
}

.dialog-wait-ct .spinner {
    display: inline-block;
}

.dialog-wait-ct span {
    vertical-align: 4px;
    padding-left: 10px;
}

.dialog-list-ct {
    max-height: 230px;
    overflow-x: auto;
    border: 1px solid #CCC;
    margin-bottom: 0px;
}

/* HACK: https://github.com/patternfly/patternfly/issues/255 */
input[type=number] {
  padding: 0 0 0 5px;
}

/* Make a dialog visible */
.dialog-ct-visible {
    display: block;
}
/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
 */

.cockpit-log-panel {
    border: 0;
}

.cockpit-log-panel .panel-heading {
    background-color: #333;
    border-color: #333;
    color: #fff;
    padding-left: 10px;
    padding-top: 5px;
    padding-bottom: 5px;
    height: auto;
}

.cockpit-log-panel .panel-body {
    padding: 0;
    border-bottom: 1px #ddd solid;
}

.cockpit-log-panel .panel-body .panel-heading {
    border-left: 1px #ddd solid;
    border-right: 1px #ddd solid;
    border-top: 0;
    border-bottom: 1px #ddd solid;
    background-color: #f5f5f5;
    font-weight: bold;
    padding-top: 2px;
    padding-bottom: 2px;
    width: auto;
    color: #333;
}

.cockpit-log-panel > .panel-heading {
    margin-top: 15px;
}

.cockpit-log-panel .cockpit-logline {
    border-left: 1px #ddd solid;
    border-right: 1px #ddd solid;
    background-color: #f5f5f5;
    padding-top: 2px;
    padding-bottom: 2px;
    padding-left: 10px;
}

.cockpit-logline {
    font-family: monospace;
    min-width: 310px;
    border-bottom: 1px solid #DDD;
    border-top: none;
}

.cockpit-logline > .row > div:first-child {
    padding-left: 20px;
}

.cockpit-log-panel .cockpit-logline:hover {
    background-color: #d4edfa;
}

.cockpit-log-panel > .cockpit-logline:hover {
    cursor: pointer;
}

.cockpit-logmsg-reboot {
    font-style: italic;
}

.cockpit-log-warning {
    display: inline-block;
    width: 20px;
    vertical-align: middle;
}

.cockpit-log-warning > i {
    color: black;
}

.cockpit-log-time {
    display: inline-block;
    width: 40px;
    vertical-align: middle;
}

.cockpit-log-service {
    width: 200px;
    margin-left: 10px;
}

.cockpit-log-service-container {
    display: inline-block;
    width: 200px;
    margin-left: 10px;
}

.cockpit-log-service-reduced {
    width: -moz-calc(100% - 70px);
    width: -webkit-calc(100% - 70px);
    width: calc(100% - 70px);
}

.cockpit-log-message {
    width: -moz-calc(100% - 300px);
    width: -webkit-calc(100% - 300px);
    width: calc(100% - 300px);
}

.cockpit-log-message,  .cockpit-log-service, .cockpit-log-service-reduced {
    text-overflow: ellipsis;
    overflow: hidden;
    display: inline-block;
    white-space: nowrap;
    vertical-align: middle;
}

.plot-unit {
    display:      inline-block;
    width:        28px;
    font-size:    smaller;
    text-align:   right;
    color:        #545454;
    margin-right: 7px;
}

.plot-title {
    color: black;
}

.flot-y-axis .flot-tick-label {
    width: 28px;
    margin-right: 7px;
}

.flot-x-axis .flot-tick-label {
    margin-top: 3px;
}

.zoom-controls {
    visibility: hidden;
}

.show-zoom-controls .zoom-controls {
    visibility: visible;
}

.show-zoom-cursor .zoomable-plot {
    cursor: ew-resize;
}

.standard-zoom-controls {
    text-align:    right;       /* on the right */
    margin-bottom: -15px;       /* overlapping with the title */
    z-index:       1;           /* but on top of it */
    position:      relative;
}
/* Panels don't draw borders between them */
.panel > .table > tbody:first-child td {
    border-top: 1px solid rgb(221, 221, 221);
}

/* Table headers should not generate a double border */
.panel .table thead tr th {
    border-bottom: none;
}

.panel-heading {
    background: #F5F5F5;
    height: 44px;
}

/* Vertically center dropdown buttons in panel headers */
.panel-heading .btn {
    margin-top: -3px;
}

/*
 * Fix up table row hovering.
 *
 * When you hover over table rows it's because they're clickable.
 * Make the table row hover color match the list-group-item.
 */
.table-hover > tbody > tr > td,
.table-hover > tbody > tr > th,
.dialog-list-ct .list-group-item {
    cursor: pointer;
}
.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th,
.dialog-list-ct .list-group-item:hover:not(.active) {
    background-color: #d4edfa;
}

/* Override patternfly to fit buttons and such */
.table > thead > tr > th,
.table > tbody > tr > td {
    padding: 8px;
}

/* Override the heavy patternfly headers */
.table > thead {
    background-image: none;
    background-color: #fff;
}

/* Make things line up */
.table tbody tr td:first-child,
.table thead tr th:first-child {
    padding-left: 15px;
}

.table tbody tr td:last-child,
.table thead tr th:last-child {
    padding-right: 15px;
}

.info-table-ct > tr > td,
.info-table-ct > tbody > tr > td {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    padding-left: 0.75em;
    padding-top: 0.25em;
    vertical-align: top;
    line-height: 26px;
}

/* Match the form-table-ct CSS equivalent */
.info-table-ct > tr > td:first-child,
.info-table-ct > tbody > tr > td:first-child {
    text-align: left;
    white-space: nowrap;
    width: 5px;
    color: #888888;
}

.info-table-ct > tr > td:not(:first-child),
.info-table-ct > tbody > tr > td:not(:first-child) {
    color: black;
}

.info-table-ct > tr > td button,
.info-table-ct > tbody > tr > td button {
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
}

.form-table-ct {
    width: 100%;
}

.form-table-ct td {
    padding-left: 0.75em;
    padding-top: 0.25em;
    line-height: 26px;
}

.form-table-ct td.top {
    vertical-align: top;
}

.form-table-ct td:first-child {
    text-align: right;
    white-space: nowrap;
    color: #888888;
    width: 5px; /* will be expanded by nowrap */
}

.form-table-ct td[colspan] {
    text-align: inherit;
}

.form-table-ct td {
    height: 26px;
}

.form-table-ct td.header {
    font-weight: bold;
    text-align: left;
    color: #4D5258;
    padding: 20px 0 10px 0;
}

.form-table-ct label input[type='radio'],
.form-table-ct label input[type='checkbox'] {
    margin-right: 4px;
}

.form-table-ct label {
    margin-bottom: 0px;
}

.form-table-ct label span {
    vertical-align: super;
}

/* Break up sidebar in columns in smaller sizes*/

@media (min-width: 992px) {
    .info-table-ct-container .info-table-ct {
        table-layout: fixed;
        width: 100%;
    }
}
/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
 */
#create-timer {
    display: none;
}
.vertical-scroll {
    max-height: 150px;
    overflow-y: scroll;
}

.position-colon {
    display: inline-block;
}

div#boot {
    display: inline-block;
    float: right;
}

div#boot-or-specific-time {
    width: 170px;
    display: inline-block;
}

div#drop-time {
    width: 100px;
    display: inline-block;
}

input#boot-time {
    width: 50px;
    display: inline-block;
    position: relative;
    top: 2px;
}

.hr, .min {
    width:30px;
    display: inline-block;
}

.form-inline {
    background: #f4f4f4;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: #bababa;
    padding: 4px;
}

#boot-label {
    position: relative;
    right: 8px;
    white-space: nowrap;
    color: #888888;
}

#repeat-time .form-inline:first-of-type {
    border-top: 1px solid #bababa;
}

#repeat-time [data-content="month-days"] {
    width: 75px;
}

#repeat-time [data-content="week-days"] {
    width: 100px;
}

#repeat-time [data-content="close"] {
    position: relative;
    float: right;
    right: 8px;
    top: 2px;
}

#repeat-time [data-content="add"] {
    position: relative;
    float: right;
    right: 4px;
    top: 2px;
}

#repeat-time [data-provide="datepicker"] {
    width: 120px;
}

[data-content='day-error'].repeat-error {
    display: block;
    font-size: 11px;
    color: #4d5258;
    line-height: 14px;
}

.has-error {
    border-color: #cc0000;
}

.has-error:hover {
    border-color: #990000;
}

.has-error:focus {
    border-color: #990000;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff3333;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff3333;
}

.repeat-error {
    display: block;
    font-size: 11px;
    color: #cc0000;
    line-height: 14px;
}

#services-page .datepicker-dropdown .prev,
#services-page .datepicker-dropdown .next {
    display: none;
    visibility: hidden;
}

.date {
    width:120px;
}

#hr-error, #min-error {
    font-size: 11px;
    line-height: 13px;
}

.help-block {
    position: relative;
    bottom: 6px;
}

@media (min-width: 500px) {
    .cockpit-timer-modal-md {
        width: 500px;
    }
    .form-inline .form-control {
        display: inline-block;
        width: 30px;
        vertical-align: middle;
    }
    .form-inline .date .bootstrap-datepicker {
        width: 100px;
    }
}
a.disabled {
    text-decoration: none;
    pointer-events: none;
    cursor: default;
    color: #000;
}

.popover {
    max-width: none;
    white-space: nowrap;
}

.systime-inline form .pficon-close,
.systime-inline form .fa-plus {
    height: 26px;
    width: 26px;
    padding: 4px;
    float: right;
    margin-left: 5px;
}

.systime-inline .form-inline {
    background: #f4f4f4;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: #bababa;
    padding: 4px;
}

.systime-inline .form-inline:first-of-type {
    border-top: 1px solid #bababa;
}

.systime-inline .form-control {
    margin: 0 4px;
}

.systime-inline .form-group:first-of-type .form-control {
    margin: 0 4px 0 0;
}

.systime-inline .form-group .form-control {
    width: 214px;
}

/* Make sure error message don't overflow the dialog */

.realms-op-diagnostics {
    max-width: 550px;
    text-align: left;
    max-height: 200px;
}

.realms-op-wait-message {
    margin-left: 10px;
    float: left;
    margin-top: 3px;
}

.realms-op-address-spinner {
    margin-left: -30px;
    margin-top:    2px;
}

.realms-op-address-error {
    margin-left: -30px;
    margin-top:    2px;
    color:         red;
}

.realms-op-zero-width {
    width: 0px;
}

.realms-op-error {
    text-align: left;
    font-weight: bold;
    overflow: auto;
    max-width: 550px;
    max-height: 200px;
}

/* Other styles */

.fa-red {
    color: red;
}

.small-messages {
    font-size: smaller;
}

#server-graph-toolbar .dropdown {
    display: inline-block;
}

#server-graph-toolbar .dropdown-toggle span {
    width: 6em;
    text-align: left;
    padding-left: 5px;
    display: inline-block;
}

.server-graph {
    height: 120px;
}

.server-graph-legend {
    list-style-type: none;
    padding: 30px 40px;
    float: right;
}

.server-graph-legend i {
    padding-right: 3px;
    font-size: 14px;
}

.server-graph-legend .cpu-io-wait i {
    color: #e41a1c;
}

.server-graph-legend .cpu-kernel i {
    color: #ff7f00;
}

.server-graph-legend .cpu-user i {
    color: #377eb8;
}

.server-graph-legend .cpu-nice i {
    color: #4daf4a;
}

.server-graph-legend .memory-swap i {
    color: #e41a1c;
}

.server-graph-legend .memory-cached i {
    color: #ff7f00;
}

.server-graph-legend .memory-used i {
    color: #377eb8;
}

.server-graph-legend .memory-free i {
    color: #4daf4a;
}

#cpu_status_graph,
#memory_status_graph {
    height: 400px;
    padding: 20px;
}

#sich-note-1,
#sich-note-2 {
    margin: 0;
}
#shutdown-dialog td {
  padding-right: 20px;
  vertical-align: top;
}

#shutdown-dialog .opt {
  padding: 1px 10px;
}

#shutdown-dialog .dropdown {
  min-width: 150px;
}

#shutdown-group {
  overflow: visible;
}

#shutdown-dialog textarea {
    resize: none;
    margin-bottom: 10px;
}

#shutdown-dialog input {
    display: inline;
    width: 10em;
}

#shutdown-dialog .shutdown-hours,
#shutdown-dialog .shutdown-minutes {
    width: 3em;
}

#system_information_ssh_keys .list-group-item {
    cursor: auto;
}

#system_information_hardware_text,
#system_information_os_text {
    overflow: visible;
    white-space: normal;
    word-wrap: break-word;
}

@media (min-width: 500px) {
  .cockpit-modal-md {
    width: 400px;
  }
}

/* Make sure to not break log message lines in order to preserve information */
#journal-entry .info-table-ct td {
    white-space: normal;
    word-break: break-all;
}

.service-unit-description {
    font-weight: bold;
}

.service-unit-data {
    text-align: right;
    white-space: nowrap;
}

.service-unit-failed {
    color: red;
}

.service-action-btn ul {
    right: 0px;
    left: auto;
    min-width: 0;
    text-align: left;
}

.service-panel td:first-child {
    text-align: left;
}

.service-panel span {
    font-weight: bold;
}

.service-panel td:last-child {
    text-align: right;
}

.service-panel table {
    width: 100%;
}

#services > .container-fluid {
    margin-top: 5em;
}

.service-template input {
    width: 50em;
}

#journal-current-day-menu dropdown-toggle {
    padding-left: 10px;
}

#journal-box {
    margin-top: 5em;
}

#journal-entry-message {
    margin: 10px;
}

#journal-entry-fields {
    margin-bottom: 10px;
}

/* Extra content header */

.content-header-extra {
    background: #f5f5f5;
    border-bottom: 1px solid #ddd;
    padding: 10px 20px;
    width: 100%;
    z-index: 900;
    top: 0;
}

.content-header-extra .btn-group:not(:first-child) {
    padding-left: 20px;
}

/* Override cockpit */
.form-table-ct {
    width: 80%;
}

.form-table-ct td.top {
    color: #151515;
	text-align: left;
}

/* Align table caption/title */
table.listing.listing-ct > caption {
  padding: 5px 10px 10px !important;
  font-weight: 300;
  margin-top: 0;
}

#motd {
    background-color: transparent;
    border: none;
    font-size: 14px;
    padding: 0px;
    margin: 0px;
    white-space: pre-wrap;
}

.listing > tbody > tr {
    cursor: pointer;
}

.margin-right-btn {
    margin-right: 10px;
}

.play-btn {
    min-width: 34px;
}

.sort {
    cursor: pointer;
}

.sort span {
    text-decoration: underline;
}

.sort-icon {
    width:7px;
    display:inline-block;
}

/* Align table title */
table.listing-ct -> caption {
    padding-left: 10px !important;
}

table.listing-ct > thead th:last-child, tr.listing-ct-item td:last-child {
    text-align: left !important;
}

.date {
    width: 185px;
}

.invalid {
    background-color: #ffdddd;
}

.valid {
    background-color: #ffffff;
}

.highlighted {
    background-color: #ededed !important;
}

/*# sourceMappingURL=config.css.map*/