@import "/page.css";

@import "./journal.css";
@import "./plot.css";
@import "./table.css";

@import "./timer.css";

a.disabled {
    text-decoration: none;
    pointer-events: none;
    cursor: default;
    color: #000;
}

.popover {
    max-width: none;
    white-space: nowrap;
}

.systime-inline form .pficon-close,
.systime-inline form .fa-plus {
    height: 26px;
    width: 26px;
    padding: 4px;
    float: right;
    margin-left: 5px;
}

.systime-inline .form-inline {
    background: #f4f4f4;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: #bababa;
    padding: 4px;
}

.systime-inline .form-inline:first-of-type {
    border-top: 1px solid #bababa;
}

.systime-inline .form-control {
    margin: 0 4px;
}

.systime-inline .form-group:first-of-type .form-control {
    margin: 0 4px 0 0;
}

.systime-inline .form-group .form-control {
    width: 214px;
}

/* Make sure error message don't overflow the dialog */

.realms-op-diagnostics {
    max-width: 550px;
    text-align: left;
    max-height: 200px;
}

.realms-op-wait-message {
    margin-left: 10px;
    float: left;
    margin-top: 3px;
}

.realms-op-address-spinner {
    margin-left: -30px;
    margin-top:    2px;
}

.realms-op-address-error {
    margin-left: -30px;
    margin-top:    2px;
    color:         red;
}

.realms-op-zero-width {
    width: 0px;
}

.realms-op-error {
    text-align: left;
    font-weight: bold;
    overflow: auto;
    max-width: 550px;
    max-height: 200px;
}

/* Other styles */

.fa-red {
    color: red;
}

.small-messages {
    font-size: smaller;
}

#server-graph-toolbar .dropdown {
    display: inline-block;
}

#server-graph-toolbar .dropdown-toggle span {
    width: 6em;
    text-align: left;
    padding-left: 5px;
    display: inline-block;
}

.server-graph {
    height: 120px;
}

.server-graph-legend {
    list-style-type: none;
    padding: 30px 40px;
    float: right;
}

.server-graph-legend i {
    padding-right: 3px;
    font-size: 14px;
}

.server-graph-legend .cpu-io-wait i {
    color: #e41a1c;
}

.server-graph-legend .cpu-kernel i {
    color: #ff7f00;
}

.server-graph-legend .cpu-user i {
    color: #377eb8;
}

.server-graph-legend .cpu-nice i {
    color: #4daf4a;
}

.server-graph-legend .memory-swap i {
    color: #e41a1c;
}

.server-graph-legend .memory-cached i {
    color: #ff7f00;
}

.server-graph-legend .memory-used i {
    color: #377eb8;
}

.server-graph-legend .memory-free i {
    color: #4daf4a;
}

#cpu_status_graph,
#memory_status_graph {
    height: 400px;
    padding: 20px;
}

#sich-note-1,
#sich-note-2 {
    margin: 0;
}
#shutdown-dialog td {
  padding-right: 20px;
  vertical-align: top;
}

#shutdown-dialog .opt {
  padding: 1px 10px;
}

#shutdown-dialog .dropdown {
  min-width: 150px;
}

#shutdown-group {
  overflow: visible;
}

#shutdown-dialog textarea {
    resize: none;
    margin-bottom: 10px;
}

#shutdown-dialog input {
    display: inline;
    width: 10em;
}

#shutdown-dialog .shutdown-hours,
#shutdown-dialog .shutdown-minutes {
    width: 3em;
}

#system_information_ssh_keys .list-group-item {
    cursor: auto;
}

#system_information_hardware_text,
#system_information_os_text {
    overflow: visible;
    white-space: normal;
    word-wrap: break-word;
}

@media (min-width: 500px) {
  .cockpit-modal-md {
    width: 400px;
  }
}

/* Make sure to not break log message lines in order to preserve information */
#journal-entry .info-table-ct td {
    white-space: normal;
    word-break: break-all;
}

.service-unit-description {
    font-weight: bold;
}

.service-unit-data {
    text-align: right;
    white-space: nowrap;
}

.service-unit-failed {
    color: red;
}

.service-action-btn ul {
    right: 0px;
    left: auto;
    min-width: 0;
    text-align: left;
}

.service-panel td:first-child {
    text-align: left;
}

.service-panel span {
    font-weight: bold;
}

.service-panel td:last-child {
    text-align: right;
}

.service-panel table {
    width: 100%;
}

#services > .container-fluid {
    margin-top: 5em;
}

.service-template input {
    width: 50em;
}

#journal-current-day-menu dropdown-toggle {
    padding-left: 10px;
}

#journal-box {
    margin-top: 5em;
}

#journal-entry-message {
    margin: 10px;
}

#journal-entry-fields {
    margin-bottom: 10px;
}

/* Extra content header */

.content-header-extra {
    background: #f5f5f5;
    border-bottom: 1px solid #ddd;
    padding: 10px 20px;
    width: 100%;
    z-index: 900;
    top: 0;
}

.content-header-extra .btn-group:not(:first-child) {
    padding-left: 20px;
}

/* Override cockpit */
.form-table-ct {
    width: 80%;
}

.form-table-ct td.top {
    color: #151515;
	text-align: left;
}

/* Align table caption/title */
table.listing.listing-ct > caption {
  padding: 5px 10px 10px !important;
  font-weight: 300;
  margin-top: 0;
}

#motd {
    background-color: transparent;
    border: none;
    font-size: 14px;
    padding: 0px;
    margin: 0px;
    white-space: pre-wrap;
}

.listing > tbody > tr {
    cursor: pointer;
}

.margin-right-btn {
    margin-right: 10px;
}

.play-btn {
    min-width: 34px;
}

.sort {
    cursor: pointer;
}

.sort span {
    text-decoration: underline;
}

.sort-icon {
    width:7px;
    display:inline-block;
}

/* Align table title */
table.listing-ct -> caption {
    padding-left: 10px !important;
}

table.listing-ct > thead th:last-child, tr.listing-ct-item td:last-child {
    text-align: left !important;
}

.date {
    width: 185px;
}

.invalid {
    background-color: #ffdddd;
}

.valid {
    background-color: #ffffff;
}

.highlighted {
    background-color: #ededed !important;
}
