/*!
 * Datetimepicker for Bootstrap
 *
 * Copyright 2012 Stefan Petre
 * Improvements by Andrew Rowls
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 */
.datetimepicker {
	padding: 4px;
	margin-top: 1px;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	direction: ltr;
}

.datetimepicker-inline {
	width: 220px;
}

.datetimepicker.datetimepicker-rtl {
	direction: rtl;
}

.datetimepicker.datetimepicker-rtl table tr td span {
	float: right;
}

.datetimepicker-dropdown, .datetimepicker-dropdown-left {
	top: 0;
	left: 0;
}

[class*=" datetimepicker-dropdown"]:before {
	content: '';
	display: inline-block;
	border-left: 7px solid transparent;
	border-right: 7px solid transparent;
	border-bottom: 7px solid #cccccc;
	border-bottom-color: rgba(0, 0, 0, 0.2);
	position: absolute;
}

[class*=" datetimepicker-dropdown"]:after {
	content: '';
	display: inline-block;
	border-left: 6px solid transparent;
	border-right: 6px solid transparent;
	border-bottom: 6px solid #ffffff;
	position: absolute;
}

[class*=" datetimepicker-dropdown-top"]:before {
	content: '';
	display: inline-block;
	border-left: 7px solid transparent;
	border-right: 7px solid transparent;
	border-top: 7px solid #cccccc;
	border-top-color: rgba(0, 0, 0, 0.2);
	border-bottom: 0;
}

[class*=" datetimepicker-dropdown-top"]:after {
	content: '';
	display: inline-block;
	border-left: 6px solid transparent;
	border-right: 6px solid transparent;
	border-top: 6px solid #ffffff;
	border-bottom: 0;
}

.datetimepicker-dropdown-bottom-left:before {
	top: -7px;
	right: 6px;
}

.datetimepicker-dropdown-bottom-left:after {
	top: -6px;
	right: 7px;
}

.datetimepicker-dropdown-bottom-right:before {
	top: -7px;
	left: 6px;
}

.datetimepicker-dropdown-bottom-right:after {
	top: -6px;
	left: 7px;
}

.datetimepicker-dropdown-top-left:before {
	bottom: -7px;
	right: 6px;
}

.datetimepicker-dropdown-top-left:after {
	bottom: -6px;
	right: 7px;
}

.datetimepicker-dropdown-top-right:before {
	bottom: -7px;
	left: 6px;
}

.datetimepicker-dropdown-top-right:after {
	bottom: -6px;
	left: 7px;
}

.datetimepicker > div {
	display: none;
}

.datetimepicker.minutes div.datetimepicker-minutes {
	display: block;
}

.datetimepicker.hours div.datetimepicker-hours {
	display: block;
}

.datetimepicker.days div.datetimepicker-days {
	display: block;
}

.datetimepicker.months div.datetimepicker-months {
	display: block;
}

.datetimepicker.years div.datetimepicker-years {
	display: block;
}

.datetimepicker table {
	margin: 0;
}

.datetimepicker  td,
.datetimepicker th {
	text-align: center;
	width: 20px;
	height: 20px;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	border: none;
}

.table-striped .datetimepicker table tr td,
.table-striped .datetimepicker table tr th {
	background-color: transparent;
}

.datetimepicker table tr td.minute:hover {
	background: #eeeeee;
	cursor: pointer;
}

.datetimepicker table tr td.hour:hover {
	background: #eeeeee;
	cursor: pointer;
}

.datetimepicker table tr td.day:hover {
	background: #eeeeee;
	cursor: pointer;
}

.datetimepicker table tr td.old,
.datetimepicker table tr td.new {
	color: #999999;
}

.datetimepicker table tr td.disabled,
.datetimepicker table tr td.disabled:hover {
	background: none;
	color: #999999;
	cursor: default;
}

.datetimepicker table tr td.today,
.datetimepicker table tr td.today:hover,
.datetimepicker table tr td.today.disabled,
.datetimepicker table tr td.today.disabled:hover {
	background-color: #fde19a;
	background-image: -moz-linear-gradient(top, #fdd49a, #fdf59a);
	background-image: -ms-linear-gradient(top, #fdd49a, #fdf59a);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fdd49a), to(#fdf59a));
	background-image: -webkit-linear-gradient(top, #fdd49a, #fdf59a);
	background-image: -o-linear-gradient(top, #fdd49a, #fdf59a);
	background-image: linear-gradient(to bottom, #fdd49a, #fdf59a);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fdd49a', endColorstr='#fdf59a', GradientType=0);
	border-color: #fdf59a #fdf59a #fbed50;
	border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
	filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
}

.datetimepicker table tr td.today:hover,
.datetimepicker table tr td.today:hover:hover,
.datetimepicker table tr td.today.disabled:hover,
.datetimepicker table tr td.today.disabled:hover:hover,
.datetimepicker table tr td.today:active,
.datetimepicker table tr td.today:hover:active,
.datetimepicker table tr td.today.disabled:active,
.datetimepicker table tr td.today.disabled:hover:active,
.datetimepicker table tr td.today.active,
.datetimepicker table tr td.today:hover.active,
.datetimepicker table tr td.today.disabled.active,
.datetimepicker table tr td.today.disabled:hover.active,
.datetimepicker table tr td.today.disabled,
.datetimepicker table tr td.today:hover.disabled,
.datetimepicker table tr td.today.disabled.disabled,
.datetimepicker table tr td.today.disabled:hover.disabled,
.datetimepicker table tr td.today[disabled],
.datetimepicker table tr td.today:hover[disabled],
.datetimepicker table tr td.today.disabled[disabled],
.datetimepicker table tr td.today.disabled:hover[disabled] {
	background-color: #fdf59a;
}

.datetimepicker table tr td.today:active,
.datetimepicker table tr td.today:hover:active,
.datetimepicker table tr td.today.disabled:active,
.datetimepicker table tr td.today.disabled:hover:active,
.datetimepicker table tr td.today.active,
.datetimepicker table tr td.today:hover.active,
.datetimepicker table tr td.today.disabled.active,
.datetimepicker table tr td.today.disabled:hover.active {
	background-color: #fbf069;
}

.datetimepicker table tr td.active,
.datetimepicker table tr td.active:hover,
.datetimepicker table tr td.active.disabled,
.datetimepicker table tr td.active.disabled:hover {
	background-color: #006dcc;
	background-image: -moz-linear-gradient(top, #0088cc, #0044cc);
	background-image: -ms-linear-gradient(top, #0088cc, #0044cc);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#0044cc));
	background-image: -webkit-linear-gradient(top, #0088cc, #0044cc);
	background-image: -o-linear-gradient(top, #0088cc, #0044cc);
	background-image: linear-gradient(to bottom, #0088cc, #0044cc);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0088cc', endColorstr='#0044cc', GradientType=0);
	border-color: #0044cc #0044cc #002a80;
	border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
	filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
	color: #ffffff;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}

.datetimepicker table tr td.active:hover,
.datetimepicker table tr td.active:hover:hover,
.datetimepicker table tr td.active.disabled:hover,
.datetimepicker table tr td.active.disabled:hover:hover,
.datetimepicker table tr td.active:active,
.datetimepicker table tr td.active:hover:active,
.datetimepicker table tr td.active.disabled:active,
.datetimepicker table tr td.active.disabled:hover:active,
.datetimepicker table tr td.active.active,
.datetimepicker table tr td.active:hover.active,
.datetimepicker table tr td.active.disabled.active,
.datetimepicker table tr td.active.disabled:hover.active,
.datetimepicker table tr td.active.disabled,
.datetimepicker table tr td.active:hover.disabled,
.datetimepicker table tr td.active.disabled.disabled,
.datetimepicker table tr td.active.disabled:hover.disabled,
.datetimepicker table tr td.active[disabled],
.datetimepicker table tr td.active:hover[disabled],
.datetimepicker table tr td.active.disabled[disabled],
.datetimepicker table tr td.active.disabled:hover[disabled] {
	background-color: #0044cc;
}

.datetimepicker table tr td.active:active,
.datetimepicker table tr td.active:hover:active,
.datetimepicker table tr td.active.disabled:active,
.datetimepicker table tr td.active.disabled:hover:active,
.datetimepicker table tr td.active.active,
.datetimepicker table tr td.active:hover.active,
.datetimepicker table tr td.active.disabled.active,
.datetimepicker table tr td.active.disabled:hover.active {
	background-color: #003399;
}

.datetimepicker table tr td span {
	display: block;
	width: 23%;
	height: 54px;
	line-height: 54px;
	float: left;
	margin: 1%;
	cursor: pointer;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

.datetimepicker .datetimepicker-hours span {
	height: 26px;
	line-height: 26px;
}

.datetimepicker .datetimepicker-hours table tr td span.hour_am,
.datetimepicker .datetimepicker-hours table tr td span.hour_pm {
	width: 14.6%;
}

.datetimepicker .datetimepicker-hours fieldset legend,
.datetimepicker .datetimepicker-minutes fieldset legend {
	margin-bottom: inherit;
	line-height: 30px;
}

.datetimepicker .datetimepicker-minutes span {
	height: 26px;
	line-height: 26px;
}

.datetimepicker table tr td span:hover {
	background: #eeeeee;
}

.datetimepicker table tr td span.disabled,
.datetimepicker table tr td span.disabled:hover {
	background: none;
	color: #999999;
	cursor: default;
}

.datetimepicker table tr td span.active,
.datetimepicker table tr td span.active:hover,
.datetimepicker table tr td span.active.disabled,
.datetimepicker table tr td span.active.disabled:hover {
	background-color: #006dcc;
	background-image: -moz-linear-gradient(top, #0088cc, #0044cc);
	background-image: -ms-linear-gradient(top, #0088cc, #0044cc);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#0044cc));
	background-image: -webkit-linear-gradient(top, #0088cc, #0044cc);
	background-image: -o-linear-gradient(top, #0088cc, #0044cc);
	background-image: linear-gradient(to bottom, #0088cc, #0044cc);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0088cc', endColorstr='#0044cc', GradientType=0);
	border-color: #0044cc #0044cc #002a80;
	border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
	filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
	color: #ffffff;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}

.datetimepicker table tr td span.active:hover,
.datetimepicker table tr td span.active:hover:hover,
.datetimepicker table tr td span.active.disabled:hover,
.datetimepicker table tr td span.active.disabled:hover:hover,
.datetimepicker table tr td span.active:active,
.datetimepicker table tr td span.active:hover:active,
.datetimepicker table tr td span.active.disabled:active,
.datetimepicker table tr td span.active.disabled:hover:active,
.datetimepicker table tr td span.active.active,
.datetimepicker table tr td span.active:hover.active,
.datetimepicker table tr td span.active.disabled.active,
.datetimepicker table tr td span.active.disabled:hover.active,
.datetimepicker table tr td span.active.disabled,
.datetimepicker table tr td span.active:hover.disabled,
.datetimepicker table tr td span.active.disabled.disabled,
.datetimepicker table tr td span.active.disabled:hover.disabled,
.datetimepicker table tr td span.active[disabled],
.datetimepicker table tr td span.active:hover[disabled],
.datetimepicker table tr td span.active.disabled[disabled],
.datetimepicker table tr td span.active.disabled:hover[disabled] {
	background-color: #0044cc;
}

.datetimepicker table tr td span.active:active,
.datetimepicker table tr td span.active:hover:active,
.datetimepicker table tr td span.active.disabled:active,
.datetimepicker table tr td span.active.disabled:hover:active,
.datetimepicker table tr td span.active.active,
.datetimepicker table tr td span.active:hover.active,
.datetimepicker table tr td span.active.disabled.active,
.datetimepicker table tr td span.active.disabled:hover.active {
	background-color: #003399;
}

.datetimepicker table tr td span.old {
	color: #999999;
}

.datetimepicker th.switch {
	width: 145px;
}

.datetimepicker th span.glyphicon {
	pointer-events: none;
}

.datetimepicker thead tr:first-child th,
.datetimepicker tfoot th {
	cursor: pointer;
}

.datetimepicker thead tr:first-child th:hover,
.datetimepicker tfoot th:hover {
	background: #eeeeee;
}

.input-append.date .add-on i,
.input-prepend.date .add-on i,
.input-group.date .input-group-addon span {
	cursor: pointer;
	width: 14px;
	height: 14px;
}
/**
 * Copyright (c) 2014 The xterm.js authors. All rights reserved.
 * Copyright (c) 2012-2013, Christopher Jeffrey (MIT License)
 * https://github.com/chjj/term.js
 * @license MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * Originally forked from (with the author's permission):
 *   Fabrice Bellard's javascript vt100 for jslinux:
 *   http://bellard.org/jslinux/
 *   Copyright (c) 2011 Fabrice Bellard
 *   The original design remains. The terminal itself
 *   has been extended to include xterm CSI codes, among
 *   other features.
 */

/**
 *  Default styles for xterm.js
 */

.xterm {
    font-feature-settings: "liga" 0;
    position: relative;
    user-select: none;
    -ms-user-select: none;
    -webkit-user-select: none;
}

.xterm.focus,
.xterm:focus {
    outline: none;
}

.xterm .xterm-helpers {
    position: absolute;
    top: 0;
    /**
     * The z-index of the helpers must be higher than the canvases in order for
     * IMEs to appear on top.
     */
    z-index: 10;
}

.xterm .xterm-helper-textarea {
    /*
     * HACK: to fix IE's blinking cursor
     * Move textarea out of the screen to the far left, so that the cursor is not visible.
     */
    position: absolute;
    opacity: 0;
    left: -9999em;
    top: 0;
    width: 0;
    height: 0;
    z-index: -10;
    /** Prevent wrapping so the IME appears against the textarea at the correct position */
    white-space: nowrap;
    overflow: hidden;
    resize: none;
}

.xterm .composition-view {
    /* TODO: Composition position got messed up somewhere */
    background: #000;
    color: #FFF;
    display: none;
    position: absolute;
    white-space: nowrap;
    z-index: 1;
}

.xterm .composition-view.active {
    display: block;
}

.xterm .xterm-viewport {
    /* On OS X this is required in order for the scroll bar to appear fully opaque */
    background-color: #000;
    overflow-y: scroll;
    cursor: default;
    position: absolute;
    right: 0;
    left: 0;
    top: 0;
    bottom: 0;
}

.xterm .xterm-screen {
    position: relative;
}

.xterm .xterm-screen canvas {
    position: absolute;
    left: 0;
    top: 0;
}

.xterm .xterm-scroll-area {
    visibility: hidden;
}

.xterm-char-measure-element {
    display: inline-block;
    visibility: hidden;
    position: absolute;
    top: 0;
    left: -9999em;
    line-height: normal;
}

.xterm {
    cursor: text;
}

.xterm.enable-mouse-events {
    /* When mouse events are enabled (eg. tmux), revert to the standard pointer cursor */
    cursor: default;
}

.xterm.xterm-cursor-pointer {
    cursor: pointer;
}

.xterm.column-select.focus {
    /* Column selection mode */
    cursor: crosshair;
}

.xterm .xterm-accessibility,
.xterm .xterm-message {
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    z-index: 100;
    color: transparent;
}

.xterm .live-region {
    position: absolute;
    left: -9999px;
    width: 1px;
    height: 1px;
    overflow: hidden;
}

.xterm-dim {
    opacity: 0.5;
}

.xterm-underline {
    text-decoration: underline;
}
.player-wrap {
    min-width: 672px;
    height: auto;
    overflow: hidden;
}

.player-wrap .panel-body, .player-wrap .console-ct > .terminal {
    padding: 0;
}

.dragnpan {
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}

#logs-view {
    height: 300px;
    overflow-y: scroll;
    margin-bottom: 0;
}

#recording-wrap {
    height: 100%;
}

.logs-view-log-time {
    display: inline-block;
    width: 150px;
    vertical-align: middle;
}

#input-textarea {
    width: 100%;
    heigth: 100%;
    font-family: monospace;
    resize: none;
}

#input-player-wrap {
    margin-top: 5px;
}

.panel-footer {
    padding: 5px 15px;
}

.search-result {
    margin-left: 5px;
    float: left;
}

.search-results {
    float: left;
    min-height: 25px;
}

.search-component {
    float: left;
    width: 33%;
}

.search-wrap {
    min-height: 25px;
    display:block;
    clear:both;
}

.session_time {
    margin-right:5px;
}
a {
    cursor: pointer;
}

.disabled {
    pointer-events: auto;
}

.btn {
    min-height: 26px;
    min-width: 26px;
}

.btn.disabled {
    pointer-events: auto;
}

.btn.disabled:hover {
  z-index: auto;
}

a.disabled {
    cursor: not-allowed !important;
    text-decoration: none;
    pointer-events: none;
    color: #8b8d8f;
}

a.disabled:hover {
    text-decoration: none;
}

.dropdown-menu > li > a.disabled,
.dropdown-menu > li > a.disabled:hover,
.dropdown-menu > li > a.disabled:focus {
  color: #999999;
}

.dropdown-menu > li > a.disabled:hover,
.dropdown-menu > li > a.disabled:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  cursor: default;
}

/* Limit dropdown menus to 90% of the viewport size */
.dropdown-menu {
    height: auto;
    overflow-x: hidden;
    max-height: 90vh;
}
/* Align these buttons more nicely */
.btn.fa-minus,
.btn.fa-plus {
    padding-top: 4px;
}

/* HACK: Workaround for https://github.com/patternfly/patternfly/issues/174*/

.page-ct {
    margin-top: 20px;
}

.highlight-ct {
    background-color: #d4edfa;
}

/* Well and Blankslate */

.curtains-ct {
    top: 0px;
    height: 100%;
    width: 100%;
    position: fixed;
}

.panel .well {
    margin-bottom: 0px;
    border: none;
    border-radius: 0px;
    background-color: #FAFAFA;
}

.well.blank-slate-pf {
    box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.05) inset;
    padding-top: 40px;
}

.blank-slate-pf .spinner-lg {
    height: 58px;
    width: 58px;
}

/*
 * Control buttons such as play and stop
 * Used with .btn .btn-default
 */

.btn-control-ct,
.btn-control-ct:hover {
    background-position: center center;
    background-size: 16px 16px;
    background-repeat: no-repeat;
    background-image: none;
    -webkit-border-radius: 2;
    -moz-border-radius: 2;
    border-radius: 2px;
    height: 28px;
    width: 28px;
    box-shadow: none;
}

.btn-control-ct {
    background-color: #eeeeee;
}

.btn-control-ct:hover {
   background-color: #e0e0e0;
}


/* On/off switch */

.btn-onoff-ct {
    margin: 1px 0px;
    text-transform: uppercase;
}

.btn-onoff-ct .btn {
    color: transparent;
    border-color: #B7B7B7;
    padding: 2px 6px 1px 6px;
    background-color: white;
    background-image: linear-gradient(to bottom, rgb(250, 250, 250) 0px, rgb(237, 237, 237) 100%);
    -webkit-box-shadow: none;
    box-shadow: none;
    width: 37px;
}

.btn-onoff-ct .btn:first-child {
    border-right: #00435F;
}

.btn-onoff-ct .btn:last-child {
    border-left: #00435F;
    padding-left: 5px;
}

.btn-onoff-ct .btn.active {
    background-image: none;
    width: 36px;
}

.btn-onoff-ct .btn.active:first-child {
    background-color: #0086CF;
    color: white;
    border-right: 1px solid #0071b0;
}

.btn-onoff-ct .btn.active:last-child {
    color: #000;
    border-left: 1px solid #d6d6d6;
}

.btn-onoff-ct .btn.disabled {
    pointer-events: none;
    color: transparent !important;
}

.btn-onoff-ct .btn.active.disabled {
    background-color: #888 !important;
    color: white !important;
}

/* Small list inside a dialog */
/* Alert fixups */

/* HACK: word-wrap workaround for long alerts https://github.com/patternfly/patternfly/issues/491 */

.modal-content .alert {
    text-align: left;
    padding-top: 5px;
    padding-bottom: 5px;
    word-wrap: break-word;
}

.modal-content .alert .fa {
    position: absolute;
    left: 10px;
    top: 6px;
    font-size: 20px;
}

.modal-content .alert .pficon {
    top: 5px;
}

.alert.alert-danger .fa {
    color: #af151a;
}

/* Dialog patterns */

.dialog-wait-ct {
    margin-top: 3px;
}

.dialog-wait-ct .spinner {
    display: inline-block;
}

.dialog-wait-ct span {
    vertical-align: 4px;
    padding-left: 10px;
}

.dialog-list-ct {
    max-height: 230px;
    overflow-x: auto;
    border: 1px solid #CCC;
    margin-bottom: 0px;
}

/* HACK: https://github.com/patternfly/patternfly/issues/255 */
input[type=number] {
  padding: 0 0 0 5px;
}

/* Make a dialog visible */
.dialog-ct-visible {
    display: block;
}
/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
 */

.cockpit-log-panel {
    border: 0;
}

.cockpit-log-panel .panel-heading {
    background-color: #333;
    border-color: #333;
    color: #fff;
    padding-left: 10px;
    padding-top: 5px;
    padding-bottom: 5px;
    height: auto;
}

.cockpit-log-panel .panel-body {
    padding: 0;
    border-bottom: 1px #ddd solid;
}

.cockpit-log-panel .panel-body .panel-heading {
    border-left: 1px #ddd solid;
    border-right: 1px #ddd solid;
    border-top: 0;
    border-bottom: 1px #ddd solid;
    background-color: #f5f5f5;
    font-weight: bold;
    padding-top: 2px;
    padding-bottom: 2px;
    width: auto;
    color: #333;
}

.cockpit-log-panel > .panel-heading {
    margin-top: 15px;
}

.cockpit-log-panel .cockpit-logline {
    border-left: 1px #ddd solid;
    border-right: 1px #ddd solid;
    background-color: #f5f5f5;
    padding-top: 2px;
    padding-bottom: 2px;
    padding-left: 10px;
}

.cockpit-logline {
    font-family: monospace;
    min-width: 310px;
    border-bottom: 1px solid #DDD;
    border-top: none;
}

.cockpit-logline > .row > div:first-child {
    padding-left: 20px;
}

.cockpit-log-panel .cockpit-logline:hover {
    background-color: #d4edfa;
}

.cockpit-log-panel > .cockpit-logline:hover {
    cursor: pointer;
}

.cockpit-logmsg-reboot {
    font-style: italic;
}

.cockpit-log-warning {
    display: inline-block;
    width: 20px;
    vertical-align: middle;
}

.cockpit-log-warning > i {
    color: black;
}

.cockpit-log-time {
    display: inline-block;
    width: 40px;
    vertical-align: middle;
}

.cockpit-log-service {
    width: 200px;
    margin-left: 10px;
}

.cockpit-log-service-container {
    display: inline-block;
    width: 200px;
    margin-left: 10px;
}

.cockpit-log-service-reduced {
    width: -moz-calc(100% - 70px);
    width: -webkit-calc(100% - 70px);
    width: calc(100% - 70px);
}

.cockpit-log-message {
    width: -moz-calc(100% - 300px);
    width: -webkit-calc(100% - 300px);
    width: calc(100% - 300px);
}

.cockpit-log-message,  .cockpit-log-service, .cockpit-log-service-reduced {
    text-overflow: ellipsis;
    overflow: hidden;
    display: inline-block;
    white-space: nowrap;
    vertical-align: middle;
}

.plot-unit {
    display:      inline-block;
    width:        28px;
    font-size:    smaller;
    text-align:   right;
    color:        #545454;
    margin-right: 7px;
}

.plot-title {
    color: black;
}

.flot-y-axis .flot-tick-label {
    width: 28px;
    margin-right: 7px;
}

.flot-x-axis .flot-tick-label {
    margin-top: 3px;
}

.zoom-controls {
    visibility: hidden;
}

.show-zoom-controls .zoom-controls {
    visibility: visible;
}

.show-zoom-cursor .zoomable-plot {
    cursor: ew-resize;
}

.standard-zoom-controls {
    text-align:    right;       /* on the right */
    margin-bottom: -15px;       /* overlapping with the title */
    z-index:       1;           /* but on top of it */
    position:      relative;
}
/* Panels don't draw borders between them */
.panel > .table > tbody:first-child td {
    border-top: 1px solid rgb(221, 221, 221);
}

/* Table headers should not generate a double border */
.panel .table thead tr th {
    border-bottom: none;
}

.panel-heading {
    background: #F5F5F5;
    height: 44px;
}

/* Vertically center dropdown buttons in panel headers */
.panel-heading .btn {
    margin-top: -3px;
}

/*
 * Fix up table row hovering.
 *
 * When you hover over table rows it's because they're clickable.
 * Make the table row hover color match the list-group-item.
 */
.table-hover > tbody > tr > td,
.table-hover > tbody > tr > th,
.dialog-list-ct .list-group-item {
    cursor: pointer;
}
.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th,
.dialog-list-ct .list-group-item:hover:not(.active) {
    background-color: #d4edfa;
}

/* Override patternfly to fit buttons and such */
.table > thead > tr > th,
.table > tbody > tr > td {
    padding: 8px;
}

/* Override the heavy patternfly headers */
.table > thead {
    background-image: none;
    background-color: #fff;
}

/* Make things line up */
.table tbody tr td:first-child,
.table thead tr th:first-child {
    padding-left: 15px;
}

.table tbody tr td:last-child,
.table thead tr th:last-child {
    padding-right: 15px;
}

.info-table-ct > tr > td,
.info-table-ct > tbody > tr > td {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    padding-left: 0.75em;
    padding-top: 0.25em;
    vertical-align: top;
    line-height: 26px;
}

/* Match the form-table-ct CSS equivalent */
.info-table-ct > tr > td:first-child,
.info-table-ct > tbody > tr > td:first-child {
    text-align: left;
    white-space: nowrap;
    width: 5px;
    color: #888888;
}

.info-table-ct > tr > td:not(:first-child),
.info-table-ct > tbody > tr > td:not(:first-child) {
    color: black;
}

.info-table-ct > tr > td button,
.info-table-ct > tbody > tr > td button {
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
}

.form-table-ct {
    width: 100%;
}

.form-table-ct td {
    padding-left: 0.75em;
    padding-top: 0.25em;
    line-height: 26px;
}

.form-table-ct td.top {
    vertical-align: top;
}

.form-table-ct td:first-child {
    text-align: right;
    white-space: nowrap;
    color: #888888;
    width: 5px; /* will be expanded by nowrap */
}

.form-table-ct td[colspan] {
    text-align: inherit;
}

.form-table-ct td {
    height: 26px;
}

.form-table-ct td.header {
    font-weight: bold;
    text-align: left;
    color: #4D5258;
    padding: 20px 0 10px 0;
}

.form-table-ct label input[type='radio'],
.form-table-ct label input[type='checkbox'] {
    margin-right: 4px;
}

.form-table-ct label {
    margin-bottom: 0px;
}

.form-table-ct label span {
    vertical-align: super;
}

/* Break up sidebar in columns in smaller sizes*/

@media (min-width: 992px) {
    .info-table-ct-container .info-table-ct {
        table-layout: fixed;
        width: 100%;
    }
}
/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
 */
#create-timer {
    display: none;
}
.vertical-scroll {
    max-height: 150px;
    overflow-y: scroll;
}

.position-colon {
    display: inline-block;
}

div#boot {
    display: inline-block;
    float: right;
}

div#boot-or-specific-time {
    width: 170px;
    display: inline-block;
}

div#drop-time {
    width: 100px;
    display: inline-block;
}

input#boot-time {
    width: 50px;
    display: inline-block;
    position: relative;
    top: 2px;
}

.hr, .min {
    width:30px;
    display: inline-block;
}

.form-inline {
    background: #f4f4f4;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: #bababa;
    padding: 4px;
}

#boot-label {
    position: relative;
    right: 8px;
    white-space: nowrap;
    color: #888888;
}

#repeat-time .form-inline:first-of-type {
    border-top: 1px solid #bababa;
}

#repeat-time [data-content="month-days"] {
    width: 75px;
}

#repeat-time [data-content="week-days"] {
    width: 100px;
}

#repeat-time [data-content="close"] {
    position: relative;
    float: right;
    right: 8px;
    top: 2px;
}

#repeat-time [data-content="add"] {
    position: relative;
    float: right;
    right: 4px;
    top: 2px;
}

#repeat-time [data-provide="datepicker"] {
    width: 120px;
}

[data-content='day-error'].repeat-error {
    display: block;
    font-size: 11px;
    color: #4d5258;
    line-height: 14px;
}

.has-error {
    border-color: #cc0000;
}

.has-error:hover {
    border-color: #990000;
}

.has-error:focus {
    border-color: #990000;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff3333;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff3333;
}

.repeat-error {
    display: block;
    font-size: 11px;
    color: #cc0000;
    line-height: 14px;
}

#services-page .datepicker-dropdown .prev,
#services-page .datepicker-dropdown .next {
    display: none;
    visibility: hidden;
}

.date {
    width:120px;
}

#hr-error, #min-error {
    font-size: 11px;
    line-height: 13px;
}

.help-block {
    position: relative;
    bottom: 6px;
}

@media (min-width: 500px) {
    .cockpit-timer-modal-md {
        width: 500px;
    }
    .form-inline .form-control {
        display: inline-block;
        width: 30px;
        vertical-align: middle;
    }
    .form-inline .date .bootstrap-datepicker {
        width: 100px;
    }
}
a.disabled {
    text-decoration: none;
    pointer-events: none;
    cursor: default;
    color: #000;
}

.popover {
    max-width: none;
    white-space: nowrap;
}

.systime-inline form .pficon-close,
.systime-inline form .fa-plus {
    height: 26px;
    width: 26px;
    padding: 4px;
    float: right;
    margin-left: 5px;
}

.systime-inline .form-inline {
    background: #f4f4f4;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: #bababa;
    padding: 4px;
}

.systime-inline .form-inline:first-of-type {
    border-top: 1px solid #bababa;
}

.systime-inline .form-control {
    margin: 0 4px;
}

.systime-inline .form-group:first-of-type .form-control {
    margin: 0 4px 0 0;
}

.systime-inline .form-group .form-control {
    width: 214px;
}

/* Make sure error message don't overflow the dialog */

.realms-op-diagnostics {
    max-width: 550px;
    text-align: left;
    max-height: 200px;
}

.realms-op-wait-message {
    margin-left: 10px;
    float: left;
    margin-top: 3px;
}

.realms-op-address-spinner {
    margin-left: -30px;
    margin-top:    2px;
}

.realms-op-address-error {
    margin-left: -30px;
    margin-top:    2px;
    color:         red;
}

.realms-op-zero-width {
    width: 0px;
}

.realms-op-error {
    text-align: left;
    font-weight: bold;
    overflow: auto;
    max-width: 550px;
    max-height: 200px;
}

/* Other styles */

.fa-red {
    color: red;
}

.small-messages {
    font-size: smaller;
}

#server-graph-toolbar .dropdown {
    display: inline-block;
}

#server-graph-toolbar .dropdown-toggle span {
    width: 6em;
    text-align: left;
    padding-left: 5px;
    display: inline-block;
}

.server-graph {
    height: 120px;
}

.server-graph-legend {
    list-style-type: none;
    padding: 30px 40px;
    float: right;
}

.server-graph-legend i {
    padding-right: 3px;
    font-size: 14px;
}

.server-graph-legend .cpu-io-wait i {
    color: #e41a1c;
}

.server-graph-legend .cpu-kernel i {
    color: #ff7f00;
}

.server-graph-legend .cpu-user i {
    color: #377eb8;
}

.server-graph-legend .cpu-nice i {
    color: #4daf4a;
}

.server-graph-legend .memory-swap i {
    color: #e41a1c;
}

.server-graph-legend .memory-cached i {
    color: #ff7f00;
}

.server-graph-legend .memory-used i {
    color: #377eb8;
}

.server-graph-legend .memory-free i {
    color: #4daf4a;
}

#cpu_status_graph,
#memory_status_graph {
    height: 400px;
    padding: 20px;
}

#sich-note-1,
#sich-note-2 {
    margin: 0;
}
#shutdown-dialog td {
  padding-right: 20px;
  vertical-align: top;
}

#shutdown-dialog .opt {
  padding: 1px 10px;
}

#shutdown-dialog .dropdown {
  min-width: 150px;
}

#shutdown-group {
  overflow: visible;
}

#shutdown-dialog textarea {
    resize: none;
    margin-bottom: 10px;
}

#shutdown-dialog input {
    display: inline;
    width: 10em;
}

#shutdown-dialog .shutdown-hours,
#shutdown-dialog .shutdown-minutes {
    width: 3em;
}

#system_information_ssh_keys .list-group-item {
    cursor: auto;
}

#system_information_hardware_text,
#system_information_os_text {
    overflow: visible;
    white-space: normal;
    word-wrap: break-word;
}

@media (min-width: 500px) {
  .cockpit-modal-md {
    width: 400px;
  }
}

/* Make sure to not break log message lines in order to preserve information */
#journal-entry .info-table-ct td {
    white-space: normal;
    word-break: break-all;
}

.service-unit-description {
    font-weight: bold;
}

.service-unit-data {
    text-align: right;
    white-space: nowrap;
}

.service-unit-failed {
    color: red;
}

.service-action-btn ul {
    right: 0px;
    left: auto;
    min-width: 0;
    text-align: left;
}

.service-panel td:first-child {
    text-align: left;
}

.service-panel span {
    font-weight: bold;
}

.service-panel td:last-child {
    text-align: right;
}

.service-panel table {
    width: 100%;
}

#services > .container-fluid {
    margin-top: 5em;
}

.service-template input {
    width: 50em;
}

#journal-current-day-menu dropdown-toggle {
    padding-left: 10px;
}

#journal-box {
    margin-top: 5em;
}

#journal-entry-message {
    margin: 10px;
}

#journal-entry-fields {
    margin-bottom: 10px;
}

/* Extra content header */

.content-header-extra {
    background: #f5f5f5;
    border-bottom: 1px solid #ddd;
    padding: 10px 20px;
    width: 100%;
    z-index: 900;
    top: 0;
}

.content-header-extra .btn-group:not(:first-child) {
    padding-left: 20px;
}

/* Override cockpit */
.form-table-ct {
    width: 80%;
}

.form-table-ct td.top {
    color: #151515;
	text-align: left;
}

/* Align table caption/title */
table.listing.listing-ct > caption {
  padding: 5px 10px 10px !important;
  font-weight: 300;
  margin-top: 0;
}

#motd {
    background-color: transparent;
    border: none;
    font-size: 14px;
    padding: 0px;
    margin: 0px;
    white-space: pre-wrap;
}

.listing > tbody > tr {
    cursor: pointer;
}

.margin-right-btn {
    margin-right: 10px;
}

.play-btn {
    min-width: 34px;
}

.sort {
    cursor: pointer;
}

.sort span {
    text-decoration: underline;
}

.sort-icon {
    width:7px;
    display:inline-block;
}

/* Align table title */
table.listing-ct -> caption {
    padding-left: 10px !important;
}

table.listing-ct > thead th:last-child, tr.listing-ct-item td:last-child {
    text-align: left !important;
}

.date {
    width: 185px;
}

.invalid {
    background-color: #ffdddd;
}

.valid {
    background-color: #ffffff;
}

.highlighted {
    background-color: #ededed !important;
}
/* Listing pattern */
table.listing-ct {
  margin-top: 15px;
  min-width: 65%;
}
table.listing-ct > caption,
table.listing-ct > thead h3 {
  font-size: 22px;
  padding: 10px 0px 10px;
  font-weight: 300;
  margin-top: 0;
}
table.listing-ct > caption {
  color: inherit;
  line-height: 1.1;
}
table.listing-ct > thead td {
  padding-top: 20px;
}
table.listing-ct > thead:first-child td {
  padding-top: 0;
}
table.listing-ct > thead td > a {
  line-height: 30px;
  padding: 10px 0 10px;
}
table.listing-ct > thead th {
  border-top: 1px solid #f1f1f1;
  font-weight: normal;
  padding: 10px;
  color: #888;
}
table.listing-ct > thead th:first-child {
  padding-left: 20px;
}
table.listing-ct > thead th:last-child {
  text-align: right;
}
/* A listing item is a row in the table */
tbody > tr.listing-ct-item {
  border-top: 1px solid #f1f1f1;
  border-bottom: 1px solid #f1f1f1;
  cursor: pointer;
}
table.listing-ct > tbody:last-child {
  border-bottom: 1px solid #f1f1f1;
}
table.listing-ct > tbody + thead {
  border-top: 1px solid #f1f1f1;
}
table.listing-ct > tbody.open:last-child {
  border-bottom: none;
}
table.listing-ct > tbody.open + thead {
  border-top: none;
}
tbody > tr.listing-ct-item.listing-ct-warning {
  background-color: #fbc7c7;
}
tbody.open > tr.listing-ct-item {
  background-color: #ededed;
  border-bottom: none;
  border-top: none;
  border-left: 1px solid #ccc;
  border-right: 1px solid #ccc;
}
tbody.open > tr.listing-ct-item td,
tbody.open > tr.listing-ct-item th {
  border-top: 1px solid #ccc;
}
tbody.open td div.listing-ct-head {
  background-color: #fff;
}
tbody.open .listing-ct-panel {
  border: 1px solid #ccc;
}
tbody.open .listing-ct-panel .listing-ct-body {
  border: none;
}
tbody.open > tr.listing-ct-panel + tr.listing-ct-body {
  border-top: none;
}
tbody.open > tr.listing-ct-panel td div.listing-ct-head {
  border: none;
  border-bottom: 1px solid #ccc;
}
/* only highlight the row if navigation is available */
tbody:not(.open) > tr.listing-ct-item:not(.listing-ct-nonavigate):hover {
  background-color: #def3ff;
}
/* if we can't navigate to a row but expand is available, highlight the caret */
tbody:not(.open) > tr.listing-ct-item.listing-ct-nonavigate:hover td.listing-ct-toggle {
  color: #65bedf;
}
/* use gray for a row that's expanded or if navigation isn't available */
tbody.open > tr.listing-ct-item:hover,
tr.listing-ct-item.listing-ct-nonavigate:hover {
  background-color: #ededed;
}
/* always highlight caret when hovering over an expanded row */
tbody.open > tr.listing-ct-item:hover td.listing-ct-toggle {
  color: #65bedf;
}
tr.listing-ct-item .listing-ct-toggle {
  padding: 0 !important;
  width: 35px;
  color: #030303;
}
table.listing-ct thead .listing-ct-toggle + th,
tr.listing-ct-item .listing-ct-toggle + td,
tr.listing-ct-item .listing-ct-toggle + th {
  padding-left: 0;
}
tr:not(.listing-ct-selected) td.listing-ct-toggle:hover {
  color: #65bedf;
  background-color: #ededed;
}
tr:not(.listing-ct-selected) td.listing-ct-toggle:hover ~ td,
tr:not(.listing-ct-selected) td.listing-ct-toggle:hover ~ th {
  background-color: #ededed;
}
td.listing-ct-toggle i {
  font-size: 24px;
  visibility: hidden;
}
tr.listing-ct-item:hover td.listing-ct-toggle i,
tr.listing-ct-item td.listing-ct-toggle:hover i {
  visibility: visible;
}
td.listing-ct-toggle i:before {
  content: "\F105";
}
tbody.open td.listing-ct-toggle i {
  visibility: visible;
}
tbody.open td.listing-ct-toggle i:before {
  content: "\F107";
}
/* Listing items have decent padding ... */
tr.listing-ct-item td {
  padding: 10px;
}
tr.listing-ct-item th {
  padding: 10px 10px 10px 15px;
}
/* Listing caption is text next to the actions, text should be similar to nav (.nav-tabs-pf > li > a)*/
.listing-ct-actions > .listing-ct-caption {
  font-size: 13px;
  vertical-align: middle;
  color: #0088ce;
  padding-right: 5px;
}
/* Listing actions can be used directly as a cell */
tr.listing-ct-item td.listing-ct-actions,
td.listing-ct-actions {
  padding: 5px 10px;
  text-align: right;
  float: none;
}
/* if the entire row is selected, highlight */
tr.listing-ct-item.listing-ct-selected {
  background-color: #0088ce;
  color: #fff;
  border-color: #007ebf;
}
tr.listing-ct-item.listing-ct-selected:hover {
  background-color: #007ebf;
  border-color: #007ebf;
}
tr.listing-ct-item.listing-ct-selected .badge {
  background-color: #00537e;
}
tr.listing-ct-item.listing-ct-selected .badge:hover {
  background-color: #003e5f;
}
.listing-ct-head .listing-ct-actions {
  margin-top: -7px;
}
tr.listing-ct-item td:first-child {
  padding-left: 20px;
}
/* The last column of a listing is always right aligned */
tr.listing-ct-item td:last-child {
  text-align: right;
}
div.listing-ct-panel {
  box-shadow: 1px 1px 1px 1px #f5f5f5;
  margin-bottom: 15px;
}
div.listing-ct-maybe {
  border: 1px dashed #ddd;
  box-shadow: none;
}
div.listing-ct-head {
  padding: 10px 10px 0 10px;
  background-color: #f5f5f5;
  border-color: #ccc;
  border-style: solid;
  border-width: 1px 1px 0 1px;
  overflow: hidden;
}
div.listing-ct-head:last-child {
  padding-bottom: 10px;
}
div.listing-ct-maybe div.listing-ct-head,
div.listing-ct-maybe div.listing-ct-body {
  background-color: #fff;
  border: none;
}
tbody.active .listing-ct-head {
  border-top: 3px solid #0099d3;
}
.listing-ct-head h3 {
  font-weight: normal;
  font-size: 18px;
  margin-top: 0px;
  margin-left: 5px;
  margin-bottom: 10px;
}
.listing-ct-head h3 i {
  float: left;
  padding-right: 7px;
}
.listing-ct-head .nav li a {
  padding-top: 0px;
  font-size: 13px;
}
.listing-ct-head .nav-tabs {
  border-bottom: none;
}
.listing-ct-head .nav-tabs-pf {
  margin-left: -10px;
}
/* To display info instead of tabs */
.listing-ct-head dl {
  display: inline-block;
  height: 1.6em;
  margin-bottom: 5px;
  white-space: nowrap;
  margin-right: 45px;
  margin-left: 5px;
}
.listing-ct-head dt {
  font-weight: normal;
  display: inline;
  margin-right: 0.5em;
  color: #888;
}
.listing-ct-head dd {
  display: inline;
  color: black;
}
.listing-ct-body {
  padding: 20px 25px;
  font-size: 13px;
  border: 1px solid #ccc;
  background-color: #fff;
}
.listing-ct-inline > .listing-ct-body {
  border: none;
  padding-top: 0px;
  padding-left: 20px;
  padding-bottom: 0px;
}
.listing-ct-inline > h3 {
  border-top: 1px solid #ccc;
  padding-top: 20px;
  margin-top: 30px;
}
.listing-ct-inline > h3:first-child {
  border-top: none;
  padding-top: 0px;
  margin-top: 20px;
}
.listing-ct-actions {
  float: right;
  min-height: 26px;
}
.listing-ct-status {
  float: right;
  clear: right;
}
.listing-ct-error {
  border-top: 1px solid #ccc;
  border-left: 1px solid #ccc;
  border-right: 1px solid #ccc;
}
.listing-ct-error.alert {
  margin-bottom: 0;
}
.listing-ct-body tt {
  font-size: 12px;
}
.listing-ct-body dl {
  margin: 0;
}
.listing-ct-body dl dd dl.inline-dl dt,
.listing-ct-body dt {
  clear: left;
  float: left;
  width: 100px;
  min-height: 26px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  color: #888;
  font-weight: normal;
}
.listing-ct-body dt {
  text-align: right;
}
.listing-ct-body dl dd dl dt {
  text-align: left;
}
.listing-ct-body dd {
  margin-left: 110px;
  min-height: 26px;
  max-width: 1000px;
  overflow: hidden;
  text-overflow: ellipsis;
}
.listing-ct-body dl.full-width dt {
  text-align: left;
  min-width: none;
  max-width: none;
  float: none;
  width: auto;
}
.listing-ct-body dl.full-width dd {
  margin-left: 0px;
}
table.listing-ct tbody.open {
  box-shadow: 1px 1px 1px 1px #f5f5f5;
}
/* By default these thincgs are hidden */
tbody tr.listing-ct-panel,
tbody tr.listing-ct-body {
  display: none;
}
/* ... unless they are in the right state */
tbody.open tr.listing-ct-head,
tbody.open tr.listing-ct-panel,
tbody.open tr.listing-ct-body {
  display: table-row;
}
tbody.open tr.listing-ct-head {
  border-color: #ccc;
  border-style: solid;
  border-width: 1px 1px 0 1px;
  border-top: 3px solid #0099d3;
  background-color: #f5f5f5;
}
tr.listing-ct-head + tr.listing-ct-head {
  border-top: none;
}
tr.listing-ct-head + tr.listing-ct-head td {
  padding: 0px 10px 0px 10px;
}
tr.listing-ct-body td {
  padding: 20px 25px;
  font-size: 13px;
}
.listing-ct-empty {
  color: #888;
  text-align: center;
  border-top: 1px solid #eee;
  border-bottom: 1px solid #eee;
}
/* Used at the end of a group of tbody to show an 'empty' message */
thead.listing-ct-empty td,
table.listing-ct > thead.listing-ct-empty td {
  padding: 10px;
}
tbody + thead.listing-ct-empty {
  display: none;
}
/* Listing pattern defaults to using full width of parent */
.listing-ct-wide {
  width: 100%;
}
div.listing-ct-head {
  overflow: visible;
}
.listing-ct-head .btn-group,
.listing-ct-head button:not(.dropdown-toggle) {
  margin-left: 0.3em;
}
table.listing-ct > caption a {
  font-size: 16px;
}
tbody tr.listing-ct-noexpand {
  cursor: default;
}
/* Fix up nav-tabs-pf to work properly */
.nav-tabs-pf > li:first-child a {
  margin-left: 0px !important;
  padding-left: 15px !important;
}
.nav-tabs-pf > li a:before {
  right: 0px !important;
}
.nav-tabs-pf > li > a:active:before,
.nav-tabs-pf > li > a:focus:before,
.nav-tabs-pf > li > a:hover:before,
.nav-tabs-pf > li.active a:before {
  height: 3px;
  left: 0px;
}

/*# sourceMappingURL=recordings.css.map*/