/* Panels don't draw borders between them */
.panel > .table > tbody:first-child td {
    border-top: 1px solid rgb(221, 221, 221);
}

/* Table headers should not generate a double border */
.panel .table thead tr th {
    border-bottom: none;
}

.panel-heading {
    background: #F5F5F5;
    height: 44px;
}

/* Vertically center dropdown buttons in panel headers */
.panel-heading .btn {
    margin-top: -3px;
}

/*
 * Fix up table row hovering.
 *
 * When you hover over table rows it's because they're clickable.
 * Make the table row hover color match the list-group-item.
 */
.table-hover > tbody > tr > td,
.table-hover > tbody > tr > th,
.dialog-list-ct .list-group-item {
    cursor: pointer;
}
.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th,
.dialog-list-ct .list-group-item:hover:not(.active) {
    background-color: #d4edfa;
}

/* Override patternfly to fit buttons and such */
.table > thead > tr > th,
.table > tbody > tr > td {
    padding: 8px;
}

/* Override the heavy patternfly headers */
.table > thead {
    background-image: none;
    background-color: #fff;
}

/* Make things line up */
.table tbody tr td:first-child,
.table thead tr th:first-child {
    padding-left: 15px;
}

.table tbody tr td:last-child,
.table thead tr th:last-child {
    padding-right: 15px;
}

.info-table-ct > tr > td,
.info-table-ct > tbody > tr > td {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    padding-left: 0.75em;
    padding-top: 0.25em;
    vertical-align: top;
    line-height: 26px;
}

/* Match the form-table-ct CSS equivalent */
.info-table-ct > tr > td:first-child,
.info-table-ct > tbody > tr > td:first-child {
    text-align: left;
    white-space: nowrap;
    width: 5px;
    color: #888888;
}

.info-table-ct > tr > td:not(:first-child),
.info-table-ct > tbody > tr > td:not(:first-child) {
    color: black;
}

.info-table-ct > tr > td button,
.info-table-ct > tbody > tr > td button {
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
}

.form-table-ct {
    width: 100%;
}

.form-table-ct td {
    padding-left: 0.75em;
    padding-top: 0.25em;
    line-height: 26px;
}

.form-table-ct td.top {
    vertical-align: top;
}

.form-table-ct td:first-child {
    text-align: right;
    white-space: nowrap;
    color: #888888;
    width: 5px; /* will be expanded by nowrap */
}

.form-table-ct td[colspan] {
    text-align: inherit;
}

.form-table-ct td {
    height: 26px;
}

.form-table-ct td.header {
    font-weight: bold;
    text-align: left;
    color: #4D5258;
    padding: 20px 0 10px 0;
}

.form-table-ct label input[type='radio'],
.form-table-ct label input[type='checkbox'] {
    margin-right: 4px;
}

.form-table-ct label {
    margin-bottom: 0px;
}

.form-table-ct label span {
    vertical-align: super;
}

/* Break up sidebar in columns in smaller sizes*/

@media (min-width: 992px) {
    .info-table-ct-container .info-table-ct {
        table-layout: fixed;
        width: 100%;
    }
}
